@@ -265,6 +265,7 @@ class RESTAPI :
     
 
     def post_summoner(self, summoner) : 
+        print(summoner)
         body = {
             "id" : summoner['id'],
             "accountid" : summoner['accountId'],
@@ -421,20 +422,19 @@ class RESTAPI :
                 "win" : participant['win']
             }
 
-            summoner = r_api.get_summoner_by_puuid(puuid)
-            leagues = self.get_league_by_summonerid(summoner['id'])
+            leagues = self.get_league_by_summonerid(body['summonerid'])
             if len(leagues) == 0 or leagues == [] :
                 api_url=URL['leagues'].format(url='/')
-                league = r_api.get_league_by_summoner_id(summoner['id'])
+                league = r_api.get_league_by_summoner_id(body['summonerid'])
                 
                 print(league)
                 self.post_league(league)
 
-            championMastery = self.get_championmastery_by_championid_and_summonerid(body['championid'], summoner['id'])
+            championMastery = self.get_championmastery_by_championid_and_summonerid(body['championid'], body['summonerid'])
             print(championMastery)
             if len(championMastery) == 0 :
                 api_url=URL['championmasteries'].format(url='/')
-                championMastery = r_api.get_champ_mastery_by_summoner_id_and_champ_id(summoner['id'], participant['championId'])
+                championMastery = r_api.get_champ_mastery_by_summoner_id_and_champ_id(body['summonerid'], participant['championId'])
                 print(championMastery)
                 self.post_championMastery(championMastery)
         
